.. Ryser documentation master file, created by
   sphinx-quickstart on Sat Dec 18 15:24:31 2010.
   Last updated: Sat Sep 14 13:56:04 BST 2013

Ryser - Latin Squares and Related Designs
=========================================

Ryser is a Python library for modelling latin squares and related designs. In
Ryser you will find components for building partial combinatorial structures
as well as algorithmic components for investigating the completability of
particular instances of such structures.

This is the homepage and documentation index for Ryser. Here you will find
all links to source code, documentation and downloads. The documentation index
follows below.

* Homepage: http://pythonhosted.org/ryser/
* Documentation: http://pythonhosted.org/ryser/#documentation
* Download: https://pypi.python.org/pypi/ryser/
* Source Code Repository: https://bitbucket.org/matthew/ryser

Documentation
-------------

.. toctree::
   :maxdepth: 2

   intro
   install
   tutorial
   modules

